import * as cloudfront from '@aws-cdk/aws-cloudfront';
import * as cdk from '@aws-cdk/core';
/**
 * @experimental
 */
export interface SimpleWebsiteConfiguration {
    /**
     * (experimental) Local path to the website folder you want to deploy on S3.
     *
     * @experimental
     */
    readonly websiteFolder: string;
    /**
     * (experimental) The index document of the website.
     *
     * @experimental
     */
    readonly indexDoc: string;
    /**
     * (experimental) The error document of the website.
     *
     * @default - No error document.
     * @experimental
     */
    readonly errorDoc?: string;
    /**
     * (experimental) Hosted Zone used to create the DNS record for the website.
     *
     * @experimental
     */
    readonly hostedZone: string;
    /**
     * (experimental) The sub-domain name you want to deploy.
     *
     * @default www  e.g. www.example.com.
     * @experimental
     */
    readonly subDomain?: string;
    /**
     * (experimental) The price class determines how many edge locations CloudFront will use for your distribution.
     *
     * @default PriceClass.PRICE_CLASS_100.
     * @see https://aws.amazon.com/cloudfront/pricing/.
     * @experimental
     */
    readonly priceClass?: cloudfront.PriceClass;
}
/**
 * @experimental
 */
export declare class CreateBasicSite extends cdk.Construct {
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: SimpleWebsiteConfiguration);
}
/**
 * @experimental
 */
export declare class CreateCloudfrontSite extends cdk.Construct {
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: SimpleWebsiteConfiguration);
}
